@@ -20,23 +20,25 @@ class Mat : public Base< eT, Mat<eT> >
   public:
   
   typedef eT                                elem_type;  //!< the type of elements stored in the matrix
-  typedef typename get_pod_type<eT>::result pod_type;   //!< if eT is non-complex, pod_type is same as eT. otherwise, pod_type is the underlying type used by std::complex
+  typedef typename get_pod_type<eT>::result  pod_type;  //!< if eT is std::complex<T>, pod_type is T; otherwise pod_type is eT
   
-  const uword  n_rows;    //!< number of rows in the matrix (read-only)
-  const uword  n_cols;    //!< number of columns in the matrix (read-only)
-  const uword  n_elem;    //!< number of elements in the matrix (read-only)
+  const uword  n_rows;    //!< number of rows     (read-only)
+  const uword  n_cols;    //!< number of columns  (read-only)
+  const uword  n_elem;    //!< number of elements (read-only)
   const uhword vec_state; //!< 0: matrix layout; 1: column vector layout; 2: row vector layout
   const uhword mem_state;
   
-  // mem_state = 0: normal matrix that can be resized; 
-  // mem_state = 1: use auxiliary memory until change in the number of elements is requested;  
-  // mem_state = 2: use auxiliary memory and don't allow the number of elements to be changed; 
-  // mem_state = 3: fixed size (e.g. via template based size specification).
+  // mem_state = 0: normal matrix which manages its own memory
+  // mem_state = 1: use auxiliary memory until a size change
+  // mem_state = 2: use auxiliary memory and don't allow the number of elements to be changed
+  // mem_state = 3: fixed size (eg. via template based size specification)
+  
+  arma_aligned const eT* const mem;  //!< pointer to the memory used for storing elements (memory is read-only)
   
-  arma_aligned const eT* const mem;  //!< pointer to the memory used by the matrix (memory is read-only)
   
   protected:
-  arma_align_mem eT mem_local[ arma_config::mat_prealloc ];
+  
+  arma_align_mem eT mem_local[ arma_config::mat_prealloc ];  // local storage, for small vectors and matrices
   
   
   public:
@@ -73,7 +75,7 @@ class Mat : public Base< eT, Mat<eT> >
   inline const Mat& operator=(Mat&& m);
   #endif
   
-  inline Mat(      eT* aux_mem, const uword aux_n_rows, const uword aux_n_cols, const bool copy_aux_mem = true, const bool strict = true);
+  inline Mat(      eT* aux_mem, const uword aux_n_rows, const uword aux_n_cols, const bool copy_aux_mem = true, const bool strict = false);
   inline Mat(const eT* aux_mem, const uword aux_n_rows, const uword aux_n_cols);
   
   arma_inline const Mat&  operator=(const eT val);
@@ -412,7 +414,8 @@ class Mat : public Base< eT, Mat<eT> >
   
   inline void  reshape(const uword in_rows, const uword in_cols);
   inline void  reshape(const SizeMat& s);
-  inline void  reshape(const uword in_rows, const uword in_cols, const uword dim);
+  
+  arma_deprecated inline void reshape(const uword in_rows, const uword in_cols, const uword dim);  //!< NOTE: don't use this form: it's deprecated
   
   
   template<typename functor>
