@@ -1,14 +1,9 @@
 // Copyright (C) 2012 Ryan Curtin
 // Copyright (C) 2012 Conrad Sanderson
 // 
-// This file is part of the Armadillo C++ library.
-// It is provided without any warranty of fitness
-// for any purpose. You can redistribute this file
-// and/or modify it under the terms of the GNU
-// Lesser General Public License (LGPL) as published
-// by the Free Software Foundation, either version 3
-// of the License or (at your option) any later version.
-// (see http://www.opensource.org/licenses for more info)
+// This Source Code Form is subject to the terms of the Mozilla Public
+// License, v. 2.0. If a copy of the MPL was not distributed with this
+// file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 //! \addtogroup SpProxy
 //! @{
@@ -106,7 +101,7 @@ class SpProxy< SpCol<eT> >
   arma_inline const uword* get_col_ptrs()    const { return Q.col_ptrs;    }
   
   arma_inline const_iterator_type     begin()                            const { return Q.begin();            }
-  arma_inline const_iterator_type     begin_col(const uword col_num)     const { return Q.begin();            }
+  arma_inline const_iterator_type     begin_col(const uword)             const { return Q.begin();            }
   arma_inline const_row_iterator_type begin_row(const uword row_num = 0) const { return Q.begin_row(row_num); }
   
   arma_inline const_iterator_type     end()                        const { return Q.end();            }
