@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2013 Conrad Sanderson
-// Copyright (C) 2008-2013 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2015 Conrad Sanderson
+// Copyright (C) 2008-2015 NICTA (www.nicta.com.au)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -211,6 +211,70 @@ namespace blas
       return eT(0);
       }
     }
+  
+  
+  
+  template<typename eT>
+  arma_inline
+  eT
+  asum(const uword n_elem, const eT* x)
+    {
+    arma_type_check((is_supported_blas_type<eT>::value == false));
+    
+    if(is_float<eT>::value)
+      {
+      blas_int n   = blas_int(n_elem);
+      blas_int inc = 1;
+      
+      typedef float T;
+      return arma_fortran(arma_sasum)(&n, (const T*)x, &inc);
+      }
+    else
+    if(is_double<eT>::value)
+      {
+      blas_int n   = blas_int(n_elem);
+      blas_int inc = 1;
+      
+      typedef double T;
+      return arma_fortran(arma_dasum)(&n, (const T*)x, &inc);
+      }
+    else
+      {
+      return eT(0);
+      }
+    }
+  
+  
+  
+  template<typename eT>
+  arma_inline
+  eT
+  nrm2(const uword n_elem, const eT* x)
+    {
+    arma_type_check((is_supported_blas_type<eT>::value == false));
+    
+    if(is_float<eT>::value)
+      {
+      blas_int n   = blas_int(n_elem);
+      blas_int inc = 1;
+      
+      typedef float T;
+      return arma_fortran(arma_snrm2)(&n, (const T*)x, &inc);
+      }
+    else
+    if(is_double<eT>::value)
+      {
+      blas_int n   = blas_int(n_elem);
+      blas_int inc = 1;
+      
+      typedef double T;
+      return arma_fortran(arma_dnrm2)(&n, (const T*)x, &inc);
+      }
+    else
+      {
+      return eT(0);
+      }
+    }
   }
 
 
