@@ -1,14 +1,9 @@
 // Copyright (C) 2012 NICTA (www.nicta.com.au)
 // Copyright (C) 2012 Conrad Sanderson
 // 
-// This file is part of the Armadillo C++ library.
-// It is provided without any warranty of fitness
-// for any purpose. You can redistribute this file
-// and/or modify it under the terms of the GNU
-// Lesser General Public License (LGPL) as published
-// by the Free Software Foundation, either version 3
-// of the License or (at your option) any later version.
-// (see http://www.opensource.org/licenses for more info)
+// This Source Code Form is subject to the terms of the Mozilla Public
+// License, v. 2.0. If a copy of the MPL was not distributed with this
+// file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 
 //! \addtogroup cond_rel
@@ -28,6 +23,8 @@ class cond_rel
 
   template<typename eT> arma_inline static bool leq(const eT A, const eT B);
   template<typename eT> arma_inline static bool geq(const eT A, const eT B);
+  
+  template<typename eT> arma_inline static eT make_neg(const eT val);
   };
 
 
