@@ -1,5 +1,5 @@
-// Copyright (C) 2010 NICTA (www.nicta.com.au)
-// Copyright (C) 2010 Conrad Sanderson
+// Copyright (C) 2010-2015 Conrad Sanderson
+// Copyright (C) 2010-2015 NICTA (www.nicta.com.au)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -15,12 +15,17 @@
 
 template<typename T1, typename T2>
 inline
-const Glue<T1, T2, glue_conv>
-conv(const Base<typename T1::elem_type,T1>& A, const Base<typename T1::elem_type,T2>& B)
+typename
+enable_if2
+  <
+  (is_arma_type<T1>::value && is_arma_type<T2>::value && is_same_type<typename T1::elem_type, typename T2::elem_type>::value),
+  const Glue<T1, T2, glue_conv>
+  >::result
+conv(const T1& A, const T2& B)
   {
   arma_extra_debug_sigprint();
   
-  return Glue<T1, T2, glue_conv>(A.get_ref(), B.get_ref());
+  return Glue<T1, T2, glue_conv>(A, B);
   }
 
 
