@@ -19,7 +19,7 @@ cov(const Base<typename T1::elem_type,T1>& X, const uword norm_type = 0)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (norm_type > 1), "cov(): norm_type must be 0 or 1");
+  arma_debug_check( (norm_type > 1), "cov(): parameter 'norm_type' must be 0 or 1" );
 
   return Op<T1, op_cov>(X.get_ref(), norm_type, 0);
   }
@@ -33,7 +33,7 @@ cov(const Base<typename T1::elem_type,T1>& A, const Base<typename T1::elem_type,
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (norm_type > 1), "cov(): norm_type must be 0 or 1");
+  arma_debug_check( (norm_type > 1), "cov(): parameter 'norm_type' must be 0 or 1" );
   
   return Glue<T1, T2, glue_cov>(A.get_ref(), B.get_ref(), norm_type);
   }
