@@ -17,15 +17,13 @@ typename
 enable_if2
   <
   is_arma_type<T1>::value,
-  const Op<T1, op_cumprod_simple>
+  const Op<T1, op_cumprod_default>
   >::result
 cumprod(const T1& X)
   {
   arma_extra_debug_sigprint();
   
-  const uword dim = resolves_to_rowvector<T1>::value ? 1 : 0;
-  
-  return Op<T1, op_cumprod_simple>(X, dim, 0);
+  return Op<T1, op_cumprod_default>(X);
   }
 
 
