@@ -17,7 +17,7 @@ typename
 enable_if2
   <
   is_arma_type<T1>::value,
-  const Op<T1, op_diff_simple>
+  const Op<T1, op_diff_default>
   >::result
 diff
   (
@@ -27,9 +27,7 @@ diff
   {
   arma_extra_debug_sigprint();
   
-  const uword dim = resolves_to_rowvector<T1>::value ? 1 : 0;
-  
-  return Op<T1, op_diff_simple>(X, k, dim);
+  return Op<T1, op_diff_default>(X, k, 0);
   }
 
 
