@@ -388,8 +388,8 @@ class herk
         
         const char trans_A = (do_trans_A) ? 'C' : 'N';
         
-        const blas_int n = C.n_cols;
-        const blas_int k = (do_trans_A) ? A.n_rows : A.n_cols;
+        const blas_int n = blas_int(C.n_cols);
+        const blas_int k = (do_trans_A) ? blas_int(A.n_rows) : blas_int(A.n_cols);
         
         const T local_alpha = (use_alpha) ? alpha : T(1);
         const T local_beta  = (use_beta)  ? beta  : T(0);
