@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2014 Conrad Sanderson
-// Copyright (C) 2008-2014 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2015 Conrad Sanderson
+// Copyright (C) 2008-2015 NICTA (www.nicta.com.au)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -10,8 +10,6 @@
 //! @{
 
 
-
-//! Class for finding maximum values in a matrix
 class op_max
   {
   public:
@@ -19,6 +17,12 @@ class op_max
   template<typename T1>
   inline static void apply(Mat<typename T1::elem_type>& out, const Op<T1,op_max>& in);
   
+  template<typename eT>
+  inline static void apply_noalias(Mat<eT>& out, const Mat<eT>& X, const uword dim, const typename arma_not_cx<eT>::result* junk = 0);
+  
+  template<typename eT>
+  inline static void apply_noalias(Mat<eT>& out, const Mat<eT>& X, const uword dim, const typename arma_cx_only<eT>::result* junk = 0);
+  
   
   //
   // for non-complex numbers
