@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2014 Conrad Sanderson
-// Copyright (C) 2008-2014 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2015 Conrad Sanderson
+// Copyright (C) 2008-2015 NICTA (www.nicta.com.au)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -11,33 +11,55 @@
 
 
 
-//! \brief
-//! For each row or for each column, find the minimum value.
-//! The result is stored in a dense matrix that has either one column or one row.
-//! The dimension, for which the minima are found, is set via the min() function.
 template<typename T1>
-inline void op_min::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_min>& in)
+inline
+void
+op_min::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_min>& in)
   {
   arma_extra_debug_sigprint();
   
   typedef typename T1::elem_type eT;
   
-  const unwrap_check<T1> tmp(in.m, out);
-  const Mat<eT>&     X = tmp.M;
-  
   const uword dim = in.aux_uword_a;
-  arma_debug_check( (dim > 1), "min(): incorrect usage. dim must be 0 or 1");
+  arma_debug_check( (dim > 1), "min(): parameter 'dim' must be 0 or 1");
+  
+  const unwrap<T1>   U(in.m);
+  const Mat<eT>& X = U.M;
+  
+  if(&out != &X)
+    {
+    op_min::apply_noalias(out, X, dim);
+    }
+  else
+    {
+    Mat<eT> tmp;
+    
+    op_min::apply_noalias(tmp, X, dim);
+    
+    out.steal_mem(tmp);
+    }
+  }
+
+
+
+template<typename eT>
+inline
+void
+op_min::apply_noalias(Mat<eT>& out, const Mat<eT>& X, const uword dim, const typename arma_not_cx<eT>::result* junk)
+  {
+  arma_extra_debug_sigprint();
+  arma_ignore(junk);
   
   const uword X_n_rows = X.n_rows;
   const uword X_n_cols = X.n_cols;
   
-  if(dim == 0)  // min in each column
+  if(dim == 0)
     {
-    arma_extra_debug_print("op_min::apply(), dim = 0");
+    arma_extra_debug_print("op_min::apply(): dim = 0");
     
-    arma_debug_check( (X_n_rows == 0), "min(): given object has zero rows" );
-
-    out.set_size(1, X_n_cols);
+    out.set_size((X_n_rows > 0) ? 1 : 0, X_n_cols);
+    
+    if(X_n_rows == 0)  { return; }
     
     eT* out_mem = out.memptr();
     
@@ -47,13 +69,68 @@ inline void op_min::apply(Mat<typename T1::elem_type>& out, const Op<T1,op_min>&
       }
     }
   else
-  if(dim == 1)  // min in each row
+  if(dim == 1)
     {
-    arma_extra_debug_print("op_min::apply(), dim = 1");
+    arma_extra_debug_print("op_min::apply(): dim = 1");
     
-    arma_debug_check( (X_n_cols == 0), "min(): given object has zero columns" );
+    out.set_size(X_n_rows, (X_n_cols > 0) ? 1 : 0);
+    
+    if(X_n_cols == 0)  { return; }
+    
+    eT* out_mem = out.memptr();
+    
+    arrayops::copy(out_mem, X.colptr(0), X_n_rows);
+    
+    for(uword col=1; col<X_n_cols; ++col)
+      {
+      const eT* col_mem = X.colptr(col);
+      
+      for(uword row=0; row<X_n_rows; ++row)
+        {
+        const eT col_val = col_mem[row];
+        
+        if(col_val < out_mem[row])  { out_mem[row] = col_val; }
+        }
+      }
+    }
+  }
 
-    out.set_size(X_n_rows, 1);
+
+
+template<typename eT>
+inline
+void
+op_min::apply_noalias(Mat<eT>& out, const Mat<eT>& X, const uword dim, const typename arma_cx_only<eT>::result* junk)
+  {
+  arma_extra_debug_sigprint();
+  arma_ignore(junk);
+  
+  const uword X_n_rows = X.n_rows;
+  const uword X_n_cols = X.n_cols;
+  
+  if(dim == 0)
+    {
+    arma_extra_debug_print("op_min::apply(): dim = 0");
+    
+    out.set_size((X_n_rows > 0) ? 1 : 0, X_n_cols);
+    
+    if(X_n_rows == 0)  { return; }
+    
+    eT* out_mem = out.memptr();
+    
+    for(uword col=0; col<X_n_cols; ++col)
+      {
+      out_mem[col] = op_min::direct_min( X.colptr(col), X_n_rows );
+      }
+    }
+  else
+  if(dim == 1)
+    {
+    arma_extra_debug_print("op_min::apply(): dim = 1");
+    
+    out.set_size(X_n_rows, (X_n_cols > 0) ? 1 : 0);
+    
+    if(X_n_cols == 0)  { return; }
     
     eT* out_mem = out.memptr();
     
@@ -186,8 +263,13 @@ op_min::min(const subview<eT>& X)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (X.n_elem == 0), "min(): given object has no elements" );
-  
+  if(X.n_elem == 0)
+    {
+    arma_debug_check(true, "min(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
+    
   const uword X_n_rows = X.n_rows;
   const uword X_n_cols = X.n_cols;
   
@@ -223,9 +305,7 @@ op_min::min(const subview<eT>& X)
     {
     for(uword col=0; col < X_n_cols; ++col)
       {
-      eT tmp_val = op_min::direct_min(X.colptr(col), X_n_rows);
-      
-      if(tmp_val < min_val) { min_val = tmp_val; }
+      min_val = (std::min)(min_val, op_min::direct_min(X.colptr(col), X_n_rows));
       }
     }
   
@@ -247,7 +327,12 @@ op_min::min(const Base<typename T1::elem_type,T1>& X)
   
   const uword n_elem = P.get_n_elem();
   
-  arma_debug_check( (n_elem == 0), "min(): given object has no elements" );
+  if(n_elem == 0)
+    {
+    arma_debug_check(true, "min(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
   
   eT min_val = priv::most_pos<eT>();
   
@@ -339,7 +424,12 @@ op_min::min_with_index(const Proxy<T1>& P, uword& index_of_min_val)
   
   const uword n_elem = P.get_n_elem();
   
-  arma_debug_check( (n_elem == 0), "min(): given object has no elements" );
+  if(n_elem == 0)
+    {
+    arma_debug_check(true, "min(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
   
   eT    best_val   = priv::most_pos<eT>();
   uword best_index = 0;
@@ -493,9 +583,16 @@ op_min::min(const subview< std::complex<T> >& X)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (X.n_elem == 0), "min(): given object has no elements" );
+  typedef typename std::complex<T> eT;
   
-  const Mat< std::complex<T> >& A = X.m;
+  if(X.n_elem == 0)
+    {
+    arma_debug_check(true, "min(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
+  
+  const Mat<eT>& A = X.m;
   
   const uword X_n_rows = X.n_rows;
   const uword X_n_cols = X.n_cols;
@@ -563,7 +660,12 @@ op_min::min(const Base<typename T1::elem_type,T1>& X)
   
   const uword n_elem = P.get_n_elem();
   
-  arma_debug_check( (n_elem == 0), "min(): given object has no elements" );
+  if(n_elem == 0)
+    {
+    arma_debug_check(true, "min(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
   
   T min_val = priv::most_pos<T>();
   
@@ -644,7 +746,12 @@ op_min::min_with_index(const Proxy<T1>& P, uword& index_of_min_val)
   
   const uword n_elem = P.get_n_elem();
   
-  arma_debug_check( (n_elem == 0), "min(): given object has no elements" );
+  if(n_elem == 0)
+    {
+    arma_debug_check(true, "min(): object has no elements");
+    
+    return Datum<eT>::nan;
+    }
   
   T best_val = priv::most_pos<T>();
   
